@@ -10,13 +10,13 @@
 
 # External documentation -------------------------------------------------------
 
-#' Tranforms dependent variables
+#' Tranforms Dependent Variables
 #'
-#' Function \code{data_transformation} transforms the dependent variable from 
-#' the formula object \code{fixed} in the given sample data set. Thus, it 
-#' returns the original sample data set with transformed dependent variable. 
-#' For the transformation five types can be chosen, particularly no, natural 
-#' log, Box-Cox, Dual and Log-Shift transformation.  
+#' Function \code{data_transformation} transforms the dependent variable from
+#' the formula object \code{fixed} in the given sample data set. Thus, it
+#' returns the original sample data set with transformed dependent variable.
+#' For the transformation five types can be chosen, particularly no, natural
+#' log, Box-Cox, Dual and Log-Shift transformation.
 #'
 #' @param fixed a two-sided linear formula object describing the
 #' fixed-effects part of the nested error linear regression model with the
@@ -28,34 +28,34 @@
 #' linear regression model, \code{smp_data} also needs to comprise the variable
 #' named in \code{smp_domains} (see \code{\link{ebp}}).
 #' @param transformation a character string. Five different transformation
-#' methods for the dependent variable can be chosen (i) no transformation ("no");
-#' (ii) natural log transformation ("log"); (iii) Box-Cox transformation
+#' methods for the dependent variable can be chosen (i) no transformation
+#' ("no"); (ii) natural log transformation ("log"); (iii) Box-Cox transformation
 #' ("box.cox"); (iv) Dual transformation ("dual"); (v) Log-Shift transformation
 #' ("log.shift")..
-#' @param lambda a scalar parameter that determines the transformations with 
-#' transformation parameter. In case of no and natural log transformation 
+#' @param lambda a scalar parameter that determines the transformations with
+#' transformation parameter. In case of no and natural log transformation
 #' \code{lambda} can be set to NULL.
 #' @return a named list with two elements, a data frame containing the data set
-#' with transformed dependent variable (\code{transformed_data}) and a shift 
-#' parameter \code{shift} if present. In case of no transformation, the original 
+#' with transformed dependent variable (\code{transformed_data}) and a shift
+#' parameter \code{shift} if present. In case of no transformation, the original
 #' data frame is returned and the shift parameter is NULL.
-#' @details For the natural log, Box-Cox and Dual transformation, the dependent variable 
-#' is shifted such that all values are greater than zero since the transformations 
-#' are not applicable for values equal to or smaller than zero. The shift is 
-#' calculated as follows: 
+#' @details For the natural log, Box-Cox and Dual transformation, the dependent
+#' variable is shifted such that all values are greater than zero since the
+#' transformations are not applicable for values equal to or smaller than zero.
+#' The shift is calculated as follows:
 #'   \deqn{shift = |min(y)| + 1 \qquad if \qquad min(y) <= 0}
 #' Function \code{data_transformation} works as a wrapper function. This means
 #' that the function manages the selection of the three different transformation
-#' functions \code{no_transform}, \code{log_transform} and \code{box_cox}. 
+#' functions \code{no_transform}, \code{log_transform} and \code{box_cox}.
 #' @seealso \code{\link[nlme]{lme}}
 #' @examples
 #' # Loading data - sample data
 #' data("eusilcA_smp")
 #'
 #' # Transform dependent variable in sample data with Box-Cox transformation
-#' transform_data <- data_transformation(eqIncome ~ gender + eqsize + cash + 
-#' self_empl + unempl_ben + age_ben + surv_ben + sick_ben + dis_ben + rent + 
-#' fam_allow + house_allow + cap_inv + tax_adj, eusilcA_smp, "box.cox", 0.7)
+#' transform_data <- data_transformation(eqIncome ~ gender + eqsize + cash +
+#'   self_empl + unempl_ben + age_ben + surv_ben + sick_ben + dis_ben + rent +
+#'   fam_allow + house_allow + cap_inv + tax_adj, eusilcA_smp, "box.cox", 0.7)
 #' @export
 
 
@@ -89,25 +89,24 @@ data_transformation <- function(fixed,
 # Function std_data_transformation only returns a data frame with transformed
 # dependent variable.
 
-std_data_transformation <- function(fixed=fixed,
+std_data_transformation <- function(fixed = fixed,
                                     smp_data,
                                     transformation,
                                     lambda) {
-
   y_vector <- as.matrix(smp_data[paste(fixed[2])])
 
-  std_transformed <- if (transformation == "box.cox"){
+  std_transformed <- if (transformation == "box.cox") {
     as.data.frame(box_cox_std(y = y_vector, lambda = lambda))
-    } else if (transformation == "dual") {
-      as.data.frame(dual_std(y = y_vector, lambda = lambda))
-    } else if (transformation == 'log.shift') {
-      as.data.frame(log_shift_opt_std(y = y_vector, lambda = lambda))
-    } else if (transformation == "log") {
-      smp_data[paste(fixed[2])]
-    } else if (transformation == "no") {
-      smp_data[paste(fixed[2])]
-    } 
-  
+  } else if (transformation == "dual") {
+    as.data.frame(dual_std(y = y_vector, lambda = lambda))
+  } else if (transformation == "log.shift") {
+    as.data.frame(log_shift_opt_std(y = y_vector, lambda = lambda))
+  } else if (transformation == "log") {
+    smp_data[paste(fixed[2])]
+  } else if (transformation == "no") {
+    smp_data[paste(fixed[2])]
+  }
+
   smp_data[paste(fixed[2])] <- std_transformed
   return(transformed_data = smp_data)
 } # End std_data_transformation
@@ -127,7 +126,7 @@ back_transformation <- function(y, transformation, lambda, shift) {
   } else if (transformation == "log.shift") {
     log_shift_opt_back(y = y, lambda = lambda)
   }
-  
+
   return(y = back_transformed)
 } # End back_transform
 
@@ -175,7 +174,7 @@ box_cox <- function(y, lambda = lambda, shift = 0) {
   with_shift <- function(y, shift) {
     min <- min(y)
     if (min <= 0) {
-      shift <- shift + abs(min(y)) +1
+      shift <- shift + abs(min(y)) + 1
     } else {
       shift <- shift
     }
@@ -186,7 +185,7 @@ box_cox <- function(y, lambda = lambda, shift = 0) {
 
   lambda_cases <- function(y, lambda = lambda) {
     lambda_absolute <- abs(lambda)
-    if (lambda_absolute <= 1e-12) {  #case lambda=0
+    if (lambda_absolute <= 1e-12) { # case lambda=0
       y <- log(y + shift)
     } else {
       y <- ((y + shift)^lambda - 1) / lambda
@@ -202,7 +201,7 @@ box_cox <- function(y, lambda = lambda, shift = 0) {
 
 # Standardized transformation: Box Cox
 
-geometric.mean <- function(x) { #for RMLE in the parameter estimation
+geometric.mean <- function(x) { # for RMLE in the parameter estimation
 
   exp(mean(log(x)))
 }
@@ -225,10 +224,9 @@ box_cox_std <- function(y, lambda) {
 
 # Back transformation: Box Cox
 box_cox_back <- function(y, lambda, shift = 0) {
-
-  lambda_cases_back <- function(y, lambda = lambda, shift){
-    if (abs(lambda) <= 1e-12) {   #case lambda=0
-      y <-  exp(y) - shift
+  lambda_cases_back <- function(y, lambda = lambda, shift) {
+    if (abs(lambda) <= 1e-12) { # case lambda=0
+      y <- exp(y) - shift
     } else {
       y <- (lambda * y + 1)^(1 / lambda) - shift
     }
@@ -243,67 +241,62 @@ box_cox_back <- function(y, lambda, shift = 0) {
 # The dual transformation ------------------------------------------------------
 
 # Transformation: dual
-dual <-  function(y, lambda = lambda, shift = 0) {
-  
+dual <- function(y, lambda = lambda, shift = 0) {
   with_shift <- function(y, shift) {
     min <- min(y)
     if (min <= 0) {
-      shift <- shift + abs(min(y)) +1
+      shift <- shift + abs(min(y)) + 1
     } else {
       shift <- shift
     }
     return(shift)
   }
-  
+
   shift <- with_shift(y = y, shift = shift)
-  
+
   lambda_absolute <- abs(lambda)
-  
-  if (lambda_absolute <= 1e-12) {  #case lambda=0
-    yt <-  log(y + shift)
-  } else if (lambda > 1e-12){
-    yt <- ((y + shift)^(lambda) - (y + shift)^(-lambda))/(2 * lambda)
+
+  if (lambda_absolute <= 1e-12) { # case lambda=0
+    yt <- log(y + shift)
+  } else if (lambda > 1e-12) {
+    yt <- ((y + shift)^(lambda) - (y + shift)^(-lambda)) / (2 * lambda)
   } else {
-    stop("lambda cannot be negative for the dual transformation")
+    stop(strwrap(prefix = " ", initial = "",
+                 "lambda cannot be negative for the dual transformation"))
   }
   return(list(y = yt, shift = shift))
-  #return(y = yt)
 }
 
 # Standardized transformation: dual
 dual_std <- function(y, lambda) {
-  
   min <- min(y)
   if (min <= 0) {
     y <- y - min + 1
   }
-  
+
   yt <- dual(y, lambda)$y
-  
+
   zt <- if (abs(lambda) > 1e-12) {
-    geo <- geometric.mean(y^(lambda -1) + y^(-lambda -1))
+    geo <- geometric.mean(y^(lambda - 1) + y^(-lambda - 1))
     zt <- yt * 2 / geo
   } else {
     zt <- geometric.mean(y) * log(y)
   }
-  
+
   y <- zt
-  
+
   return(y)
 }
 
 # Back transformation: dual
 dual_back <- function(y, lambda = lambda, shift) {
   lambda_absolute <- abs(lambda)
-  if(lambda_absolute <= 1e-12)
-  {
+  if (lambda_absolute <= 1e-12) {
     y <- exp(y) - shift
+  } else {
+    y <- (lambda * y + sqrt(lambda^2 * y^2 + 1))^(1 / lambda) - shift
   }
-  else
-  {
-    y <- (lambda * y + sqrt(lambda^2 * y^2 + 1))^(1/lambda) - shift
-  }
-  
+
   return(y = y)
 }
 
@@ -313,9 +306,7 @@ dual_back <- function(y, lambda = lambda, shift) {
 #  Transformation: log_shift_opt
 
 log_shift_opt <- function(y, lambda = lambda, shift = NULL) {
-  
-  with_shift <-  function(y, lambda) {
-    
+  with_shift <- function(y, lambda) {
     min <- min(y + lambda)
     if (min <= 0) {
       lambda <- lambda + abs(min) + 1
@@ -324,16 +315,15 @@ log_shift_opt <- function(y, lambda = lambda, shift = NULL) {
     }
     return(lambda)
   }
-  
+
   # Shift parameter
-  lambda <- with_shift(y = y, lambda = lambda )
-  
+  lambda <- with_shift(y = y, lambda = lambda)
+
   log_trafo <- function(y, lambda = lambda) {
     y <- log(y + lambda)
     return(y)
   }
   yt <- log_trafo(y = y, lambda = lambda)
-  #return(y)
   return(list(y = yt, shift = NULL))
 } # End log_shift
 
@@ -341,13 +331,12 @@ log_shift_opt <- function(y, lambda = lambda, shift = NULL) {
 
 # Standardized transformation: Log_shift_opt
 
-geometric.mean <- function(x) { #for RMLE in the parameter estimation
+geometric.mean <- function(x) { # for RMLE in the parameter estimation
   exp(mean(log(x)))
 }
 
 log_shift_opt_std <- function(y, lambda) {
-  
-  with_shift <-  function(y, lambda) {
+  with_shift <- function(y, lambda) {
     min <- min(y + lambda)
     if (min <= 0) {
       lambda <- lambda + abs(min(y)) + 1
@@ -356,10 +345,10 @@ log_shift_opt_std <- function(y, lambda) {
     }
     return(lambda)
   }
-  
+
   # Shift parameter
-  lambda <- with_shift(y = y, lambda = lambda )
-  
+  lambda <- with_shift(y = y, lambda = lambda)
+
   log_trafo_std <- function(y, lambda = lambda) {
     gm <- geometric.mean(y + lambda)
     y <- gm * log(y + lambda)
@@ -371,11 +360,10 @@ log_shift_opt_std <- function(y, lambda) {
 
 # Back transformation: log_shift_opt
 log_shift_opt_back <- function(y, lambda) {
-  log_shift_opt_back <- function(y, lambda = lambda){
-    y <-  exp(y) - lambda
+  log_shift_opt_back <- function(y, lambda = lambda) {
+    y <- exp(y) - lambda
     return(y = y)
   }
   y <- log_shift_opt_back(y = y, lambda = lambda)
   return(y = y)
 } #  End log_shift_opt
-
